# MarkdownRenderer

一个强大、灵活的 React Markdown 渲染组件，专为开发者打造，具有丰富的扩展功能。

![MarkdownRenderer预览](https://via.placeholder.com/800x400?text=MarkdownRenderer+Preview)

## ✨ 特性

- 🚀 完整支持 GitHub 风格 Markdown (GFM)
- 🎨 响应式设计，适配深色/浅色模式
- 🔍 代码块语法高亮与复制功能
- 🔢 支持数学公式渲染 (KaTeX)
- ✅ 任务列表支持
- 🔄 自动处理 HTML 混合内容
- 📱 完全响应式，支持移动端
- 🧩 模块化设计，易于扩展和自定义

## 📦 安装

```bash
# 使用npm
npm install react-markdown-renderer-integration

# 使用yarn
yarn add react-markdown-renderer-integration

# 使用pnpm
pnpm add react-markdown-renderer-integration
```

## 🚀 基础使用

### 方式一：如果您的项目使用 TailwindCSS

```tsx
import { MarkdownRenderer } from "react-markdown-renderer-integration";

function App() {
  const markdownContent = `
# Hello World

这是一个**Markdown**示例。

\`\`\`javascript
const greeting = "Hello, World!";
console.log(greeting);
\`\`\`

| 属性 | 类型 | 默认值 |
| ---- | ---- | ------ |
| name | string | - |
| age | number | 0 |
  `;

  return (
    <div className="container mx-auto p-4">
      <MarkdownRenderer content={markdownContent} />
    </div>
  );
}
```

### 方式二：如果您的项目不使用 TailwindCSS

需要额外导入样式文件：

```tsx
import { MarkdownRenderer } from "react-markdown-renderer-integration";
// 导入预编译的CSS样式
import "react-markdown-renderer-integration/dist/markdown-renderer.css";

function App() {
  const markdownContent = `# Hello World`;

  return <MarkdownRenderer content={markdownContent} />;
}
```

## 📝 Props

| 属性        | 类型      | 默认值  | 描述                                            |
| ----------- | --------- | ------- | ----------------------------------------------- |
| `content`   | `string`  | 必填    | Markdown 格式的内容字符串                       |
| `allowHtml` | `boolean` | `false` | 是否允许渲染 HTML (注意: 启用时需注意 XSS 风险) |
| `className` | `string`  | `""`    | 自定义 CSS 类名                                 |

## 🎨 特殊功能

### 代码块高亮与复制

自动为代码块添加语法高亮，并提供一键复制功能：

```jsx
const code = `function sayHello() {
  console.log("Hello world!");
}`;

<MarkdownRenderer content={`\`\`\`javascript\n${code}\n\`\`\``} />;
```

### 数学公式支持

行内公式：$E=mc^2$

块级公式：

$$
\frac{d}{dx}e^x = e^x
$$

### 任务列表

支持 GitHub 风格的任务列表：

```md
- [x] 已完成任务
- [ ] 未完成任务
```

## 🛠️ 高级用法

### 自定义样式

MarkdownRenderer 组件使用 Tailwind CSS 和内联样式，你可以通过传入`className`属性或修改组件内的样式定义来自定义外观：

```tsx
<MarkdownRenderer
  content={markdownContent}
  className="prose-lg prose-blue max-w-none"
/>
```

### 安全性考虑

默认情况下，HTML 内容会被净化以防止 XSS 攻击。如果需要渲染 HTML，请谨慎使用`allowHtml`属性：

```tsx
// 仅在信任内容源时启用
<MarkdownRenderer content={trustedContent} allowHtml={true} />
```

## 🧩 内部组件

MarkdownRenderer 内部封装了几个有用的子组件：

- **CodeBlock**: 提供代码高亮和复制功能
- **TaskListItem**: 渲染任务列表项

这些组件可以根据需要提取出来单独使用。

## 📋 支持的语言

代码块支持超过 40 种编程语言的语法高亮，包括但不限于：

- JavaScript/TypeScript
- HTML/CSS
- Python
- Java
- Ruby
- C/C++
- Bash/Shell
- Markdown
- JSON/YAML

## 💡 使用技巧

1. **大型文档处理**: 组件内置了优化逻辑，可以处理大型文档而不影响性能
2. **移动端适配**: 表格会自动添加横向滚动，确保在移动设备上正确显示
3. **深色模式**: 自动检测并适配深色模式，提供优雅的视觉体验

## 🤝 贡献

欢迎提交 Issues 或 Pull Requests 来改进这个组件。在贡献代码前，请确保：

1. 代码格式符合项目规范
2. 提交前进行充分测试
3. 提交信息清晰明了

## 📄 许可证

[MIT License](LICENSE)

---

## 🙏 致谢

本项目基于以下开源项目:

- [React Markdown](https://github.com/remarkjs/react-markdown)
- [Remark](https://github.com/remarkjs/remark)
- [Rehype](https://github.com/rehypejs/rehype)
- [KaTeX](https://github.com/KaTeX/KaTeX)
- [Syntax Highlighter](https://github.com/react-syntax-highlighter/react-syntax-highlighter)

---

Made with ❤️ by BelovedLYC
